summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--amarok/HACKING2
-rw-r--r--amarok/src/amarok.h16
-rw-r--r--amarok/src/analyzers/blockanalyzer.cpp2
-rw-r--r--amarok/src/app.cpp8
-rw-r--r--amarok/src/app.h4
-rw-r--r--amarok/src/collectionbrowser.cpp2
-rw-r--r--amarok/src/configdialog.cpp2
-rw-r--r--amarok/src/contextbrowser.cpp12
-rw-r--r--amarok/src/deletedialog.cpp8
-rw-r--r--amarok/src/editfilterdialog.cpp2
-rw-r--r--amarok/src/engine/xine/xine-engine.cpp2
-rw-r--r--amarok/src/engine/yauap/yauap-engine.cpp4
-rw-r--r--amarok/src/k3bexporter.cpp4
-rw-r--r--amarok/src/konquisidebar/universalamarok.cpp6
-rw-r--r--amarok/src/lastfm.cpp4
-rw-r--r--amarok/src/loader/loader.cpp6
-rw-r--r--amarok/src/magnatunebrowser/magnatunealbumdownloader.cpp2
-rw-r--r--amarok/src/magnatunebrowser/magnatunelistviewitems.cpp6
-rw-r--r--amarok/src/mediabrowser.cpp2
-rw-r--r--amarok/src/mediadevice/daap/daapclient.cpp4
-rw-r--r--amarok/src/mediadevice/daap/daapserver.cpp2
-rw-r--r--amarok/src/mediadevice/daap/proxy.cpp4
-rw-r--r--amarok/src/moodbar.cpp20
-rw-r--r--amarok/src/moodbar.h6
-rw-r--r--amarok/src/mountpointmanager.cpp2
-rw-r--r--amarok/src/playerwindow.cpp4
-rw-r--r--amarok/src/playlist.cpp8
-rw-r--r--amarok/src/playlistbrowser.cpp2
-rw-r--r--amarok/src/playlistbrowseritem.cpp4
-rw-r--r--amarok/src/prettypopupmenu.cpp2
-rw-r--r--amarok/src/scancontroller.cpp2
-rw-r--r--amarok/src/scriptmanager.cpp20
-rw-r--r--amarok/src/scriptmanager.h8
-rw-r--r--amarok/src/socketserver.cpp10
-rw-r--r--amarok/src/socketserver.h8
-rw-r--r--amarok/src/starmanager.cpp2
-rw-r--r--amarok/src/statusbar/queueLabel.cpp2
-rw-r--r--amarok/src/statusbar/selectLabel.h2
-rw-r--r--amarok/src/statusbar/statusBarBase.cpp8
-rw-r--r--amarok/src/statusbar/timeLabel.h2
-rw-r--r--amarok/src/statusbar/toggleLabel.h2
-rw-r--r--amarok/src/tagdialog.cpp10
-rw-r--r--amarok/src/tagguesser.cpp4
43 files changed, 116 insertions, 116 deletions
diff --git a/amarok/HACKING b/amarok/HACKING
index 5050ce26..7b9d57bf 100644
--- a/amarok/HACKING
+++ b/amarok/HACKING
@@ -78,7 +78,7 @@ good for others reading your code, and ultimately it's good for you too.
Comments are essential when adding a strange hack, like the following example:
- | /** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
+ | /** Due to xine-lib, we have to make TDEProcess close all fds, otherwise we get "device is busy" messages
| * Used by AmarokProcIO and AmarokProcess, exploiting commSetupDoneC(), a virtual method that
| * happens to be called in the forked process
| * See bug #103750 for more information.
diff --git a/amarok/src/analyzers/blockanalyzer.cpp b/amarok/src/analyzers/blockanalyzer.cpp
index e6d75dea..db14bbed 100644
--- a/amarok/src/analyzers/blockanalyzer.cpp
+++ b/amarok/src/analyzers/blockanalyzer.cpp
@@ -355,7 +355,7 @@ void
BlockAnalyzer::paletteChange( const TQPalette& ) //virtual
{
const TQColor bg = palette().active().background();
- const TQColor fg = ensureContrast( bg, KGlobalSettings::activeTitleColor() );
+ const TQColor fg = ensureContrast( bg, TDEGlobalSettings::activeTitleColor() );
m_topBarPixmap.fill( fg );
diff --git a/amarok/src/app.cpp b/amarok/src/app.cpp
index 6e0a4d84..8023b9c5 100644
--- a/amarok/src/app.cpp
+++ b/amarok/src/app.cpp
@@ -780,7 +780,7 @@ App::continueInit()
CollectionDB::instance()->checkDatabase();
m_pMediaDeviceManager = MediaDeviceManager::instance();
- m_pGlobalAccel = new KGlobalAccel( TQT_TQOBJECT(this) );
+ m_pGlobalAccel = new TDEGlobalAccel( TQT_TQOBJECT(this) );
m_pPlaylistWindow = new PlaylistWindow();
#ifdef TQ_WS_X11
m_pTray = new Amarok::TrayIcon( m_pPlaylistWindow );
@@ -860,7 +860,7 @@ App::applyColorScheme()
if( AmarokConfig::schemeKDE() )
{
- AltBase = KGlobalSettings::alternateBackgroundColor();
+ AltBase = TDEGlobalSettings::alternateBackgroundColor();
playlistWindow()->unsetPalette();
browserBar->unsetPalette();
@@ -1238,7 +1238,7 @@ KIO::Job *App::trashFiles( const KURL::List &files )
connect( job, TQT_SIGNAL( result( KIO::Job* ) ), this, TQT_SLOT( slotTrashResult( KIO::Job* ) ) );
return job;
#else
- KIO::Job* job = KIO::move( files, KGlobalSettings::trashPath() );
+ KIO::Job* job = KIO::move( files, TDEGlobalSettings::trashPath() );
return job;
#endif
}
@@ -1338,7 +1338,7 @@ namespace Amarok
TQString saveLocation( const TQString &directory )
{
globalDirsMutex.lock();
- TQString result = KGlobal::dirs()->saveLocation( "data", TQString("amarok/") + directory, true );
+ TQString result = TDEGlobal::dirs()->saveLocation( "data", TQString("amarok/") + directory, true );
globalDirsMutex.unlock();
return result;
}
diff --git a/amarok/src/app.h b/amarok/src/app.h
index ee42d6c0..c921dd50 100644
--- a/amarok/src/app.h
+++ b/amarok/src/app.h
@@ -32,7 +32,7 @@ namespace KIO { class Job; }
class KActionCollection;
class KConfig;
-class KGlobalAccel;
+class TDEGlobalAccel;
class MetaBundle;
class PlayerWidget;
class Playlist;
@@ -111,7 +111,7 @@ class LIBAMAROK_EXPORT App : public TDEApplication, public EngineObserver
void setRating( int n );
// ATTRIBUTES ------
- KGlobalAccel *m_pGlobalAccel;
+ TDEGlobalAccel *m_pGlobalAccel;
PlayerWidget *m_pPlayerWindow;
PlaylistWindow *m_pPlaylistWindow;
#ifdef TQ_WS_X11
diff --git a/amarok/src/collectionbrowser.cpp b/amarok/src/collectionbrowser.cpp
index 607af54c..70afa03c 100644
--- a/amarok/src/collectionbrowser.cpp
+++ b/amarok/src/collectionbrowser.cpp
@@ -2736,7 +2736,7 @@ CollectionView::iconForCategory( const int cat ) const
break;
}
- return KGlobal::iconLoader()->loadIcon( icon, KIcon::Toolbar, KIcon::SizeSmall );
+ return TDEGlobal::iconLoader()->loadIcon( icon, KIcon::Toolbar, KIcon::SizeSmall );
}
TQString
diff --git a/amarok/src/configdialog.cpp b/amarok/src/configdialog.cpp
index f84b98ab..a05a8d3b 100644
--- a/amarok/src/configdialog.cpp
+++ b/amarok/src/configdialog.cpp
@@ -185,7 +185,7 @@ AmarokConfigDialog::AmarokConfigDialog( TQWidget *parent, const char* name, KCon
// Show information labels (must be done after insertions)
TQObjectList *list = queryList( TQLABEL_OBJECT_NAME_STRING, "infoPixmap" );
- TQPixmap const info = KGlobal::iconLoader()->iconPath( "messagebox_info", -KIcon::SizeHuge );
+ TQPixmap const info = TDEGlobal::iconLoader()->iconPath( "messagebox_info", -KIcon::SizeHuge );
for( TQObject *label = list->first(); label; label = list->next() )
static_cast<TQLabel*>(TQT_TQWIDGET(label))->setPixmap( info );
delete list;
diff --git a/amarok/src/contextbrowser.cpp b/amarok/src/contextbrowser.cpp
index 570270a1..3a09ac7e 100644
--- a/amarok/src/contextbrowser.cpp
+++ b/amarok/src/contextbrowser.cpp
@@ -95,7 +95,7 @@ namespace Amarok
const int datediff = datetime.daysTo( now );
if( datediff >= 6*7 /*six weeks*/ ) { // return absolute month/year
- const KCalendarSystem *cal = KGlobal::locale()->calendar();
+ const KCalendarSystem *cal = TDEGlobal::locale()->calendar();
const TQDate date = datetime.date();
return i18n( "monthname year", "%1 %2" ).arg( cal->monthName(date), cal->yearString(date, false) );
}
@@ -642,7 +642,7 @@ void ContextBrowser::engineNewMetaData( const MetaBundle& bundle, bool trackChan
if ( !m_metadataHistory.first().contains( bundle.prettyTitle() ) )
{
newMetaData = true;
- const TQString timeString = KGlobal::locale()->formatTime( TQTime::currentTime() ).replace(" ", "&nbsp;"); // don't break over lines
+ const TQString timeString = TDEGlobal::locale()->formatTime( TQTime::currentTime() ).replace(" ", "&nbsp;"); // don't break over lines
m_metadataHistory.prepend( TQString( "<td valign='top'>" + timeString + "&nbsp;</td><td align='left'>" + escapeHTML( bundle.prettyTitle() ) + "</td>" ) );
}
@@ -1116,7 +1116,7 @@ public:
}
- m_amarokIconPath = TQDeepCopy<TQString>(KGlobal::iconLoader()->iconPath( "amarok",
+ m_amarokIconPath = TQDeepCopy<TQString>(TDEGlobal::iconLoader()->iconPath( "amarok",
-KIcon::SizeEnormous ) );
m_musicBrainIconPath = TQDeepCopy<TQString>(locate( "data", "amarok/images/musicbrainz.png" )
);
@@ -1774,9 +1774,9 @@ void CurrentTrackJob::showLastFm( const MetaBundle &currentTrack )
for ( TQString* url = newUrls.first(); url; url = newUrls.next() )
url->replace( TQRegExp( "^http:" ), "externalurl:" );
- const TQString skipIcon = KGlobal::iconLoader()->iconPath( Amarok::icon("next"), -KIcon::SizeSmallMedium );
- const TQString loveIcon = KGlobal::iconLoader()->iconPath( Amarok::icon("love"), -KIcon::SizeSmallMedium );
- const TQString banIcon = KGlobal::iconLoader()->iconPath( Amarok::icon("remove"), -KIcon::SizeSmallMedium );
+ const TQString skipIcon = TDEGlobal::iconLoader()->iconPath( Amarok::icon("next"), -KIcon::SizeSmallMedium );
+ const TQString loveIcon = TDEGlobal::iconLoader()->iconPath( Amarok::icon("love"), -KIcon::SizeSmallMedium );
+ const TQString banIcon = TDEGlobal::iconLoader()->iconPath( Amarok::icon("remove"), -KIcon::SizeSmallMedium );
m_HTMLSource.append( QStringx(
diff --git a/amarok/src/deletedialog.cpp b/amarok/src/deletedialog.cpp
index b57ba895..2d35605f 100644
--- a/amarok/src/deletedialog.cpp
+++ b/amarok/src/deletedialog.cpp
@@ -44,7 +44,7 @@
DeleteWidget::DeleteWidget(TQWidget *parent, const char *name)
: DeleteDialogBase(parent, name)
{
- KConfigGroup messageGroup(KGlobal::config(), "FileRemover");
+ KConfigGroup messageGroup(TDEGlobal::config(), "FileRemover");
bool deleteInstead = messageGroup.readBoolEntry("deleteInsteadOfTrash", false);
slotShouldDelete(deleteInstead);
@@ -70,12 +70,12 @@ void DeleteWidget::slotShouldDelete(bool shouldDelete)
if(shouldDelete) {
ddDeleteText->setText(i18n("<qt>These items will be <b>permanently "
"deleted</b> from your hard disk.</qt>"));
- ddWarningIcon->setPixmap(KGlobal::iconLoader()->loadIcon("messagebox_warning",
+ ddWarningIcon->setPixmap(TDEGlobal::iconLoader()->loadIcon("messagebox_warning",
KIcon::Desktop, KIcon::SizeLarge));
}
else {
ddDeleteText->setText(i18n("<qt>These items will be moved to the Trash Bin.</qt>"));
- ddWarningIcon->setPixmap(KGlobal::iconLoader()->loadIcon("trashcan_full",
+ ddWarningIcon->setPixmap(TDEGlobal::iconLoader()->loadIcon("trashcan_full",
KIcon::Desktop, KIcon::SizeLarge));
}
}
@@ -116,7 +116,7 @@ void DeleteDialog::setFiles(const KURL::List &files)
void DeleteDialog::accept()
{
- KConfigGroup messageGroup(KGlobal::config(), "FileRemover");
+ KConfigGroup messageGroup(TDEGlobal::config(), "FileRemover");
// Save user's preference
diff --git a/amarok/src/editfilterdialog.cpp b/amarok/src/editfilterdialog.cpp
index 04f3a19b..f4dbf49e 100644
--- a/amarok/src/editfilterdialog.cpp
+++ b/amarok/src/editfilterdialog.cpp
@@ -605,7 +605,7 @@ void EditFilterDialog::textWanted( const TQStringList &completion ) // SLOT
m_editKeyword->completionObject()->clear();
m_editKeyword->completionObject()->insertItems( completion );
m_editKeyword->completionObject()->setIgnoreCase( true );
- m_editKeyword->setCompletionMode( KGlobalSettings::CompletionPopup );
+ m_editKeyword->setCompletionMode( TDEGlobalSettings::CompletionPopup );
}
void EditFilterDialog::valueWanted() // SLOT
diff --git a/amarok/src/engine/xine/xine-engine.cpp b/amarok/src/engine/xine/xine-engine.cpp
index ace6bef0..abca1e14 100644
--- a/amarok/src/engine/xine/xine-engine.cpp
+++ b/amarok/src/engine/xine/xine-engine.cpp
@@ -924,7 +924,7 @@ XineEngine::XineEventListener( void *p, const xine_event_t* xineEvent )
TQString
msg = "%1 %2%";
msg = msg.arg( TQString::fromUtf8( pd->description ) )
- .arg( KGlobal::locale()->formatNumber( pd->percent, 0 ) );
+ .arg( TDEGlobal::locale()->formatNumber( pd->percent, 0 ) );
TQCustomEvent *e = new TQCustomEvent( 3002 );
e->setData( new TQString( msg ) );
diff --git a/amarok/src/engine/yauap/yauap-engine.cpp b/amarok/src/engine/yauap/yauap-engine.cpp
index b3e8f0cd..04c3b6fa 100644
--- a/amarok/src/engine/yauap/yauap-engine.cpp
+++ b/amarok/src/engine/yauap/yauap-engine.cpp
@@ -397,7 +397,7 @@ yauapEngine::initDbusConnection()
helper.clearArguments();
helper << "yauap" << "-noexit";
- if( !helper.start(KProcess::NotifyOnExit, KProcess::All))
+ if( !helper.start(TDEProcess::NotifyOnExit, TDEProcess::All))
{
debug() << "could not start yauap " << endl;
emit statusText( i18n( "could not start yauap" ) );
@@ -473,7 +473,7 @@ yauapEngine::init()
m_state = Engine::Idle;
- connect(&helper, TQT_SIGNAL(processExited(KProcess*)), TQT_SLOT(yauapProcessExited()));
+ connect(&helper, TQT_SIGNAL(processExited(TDEProcess*)), TQT_SLOT(yauapProcessExited()));
if (initDbusConnection())
return true;
diff --git a/amarok/src/k3bexporter.cpp b/amarok/src/k3bexporter.cpp
index d0893415..fbbe731d 100644
--- a/amarok/src/k3bexporter.cpp
+++ b/amarok/src/k3bexporter.cpp
@@ -167,7 +167,7 @@ void K3bExporter::exportViaCmdLine( const KURL::List &urls, int openmode )
return;
}
- KProcess *process = new KProcess;
+ TDEProcess *process = new TDEProcess;
*process << "k3b";
*process << cmdOption;
@@ -177,7 +177,7 @@ void K3bExporter::exportViaCmdLine( const KURL::List &urls, int openmode )
for( it = urls.begin(); it != end; ++it )
*process << ( *it ).path();
- if( !process->start( KProcess::DontCare ) )
+ if( !process->start( TDEProcess::DontCare ) )
KMessageBox::error( 0, i18n("Unable to start K3b.") );
}
diff --git a/amarok/src/konquisidebar/universalamarok.cpp b/amarok/src/konquisidebar/universalamarok.cpp
index 3473388f..f9da34ee 100644
--- a/amarok/src/konquisidebar/universalamarok.cpp
+++ b/amarok/src/konquisidebar/universalamarok.cpp
@@ -44,7 +44,7 @@
#include <kurldrag.h>
#include <khtmlview.h>
-#define HTML_FILE KGlobal::dirs()->saveLocation( "data", "amarok/", true ) + "contextbrowser.html"
+#define HTML_FILE TDEGlobal::dirs()->saveLocation( "data", "amarok/", true ) + "contextbrowser.html"
amarokWidget::amarokWidget( TQWidget * parent, const char * name, WFlags f )
: TQVBox(parent, name, f)
@@ -79,7 +79,7 @@ bool amarokWidget::eventFilter( TQObject *, TQEvent *e )
UniversalAmarok::UniversalAmarok(TDEInstance *inst,TQObject *parent,TQWidget *widgetParent, TQString &desktopName, const char* name):
KonqSidebarPlugin(inst,parent,widgetParent,desktopName,name)
{
- KGlobal::iconLoader()->addAppDir( "amarok" );
+ TDEGlobal::iconLoader()->addAppDir( "amarok" );
widget = new amarokWidget( widgetParent );
// widgetParent->resize(580,300);
KToolBar *topBar = new KToolBar( widget, "Topbar" );
@@ -153,7 +153,7 @@ extern "C"
{
KDE_EXPORT void* create_konqsidebar_universalamarok(TDEInstance *instance,TQObject *par,TQWidget *widp,TQString &desktopname,const char *name)
{
- KGlobal::locale()->insertCatalogue( "amarok" );
+ TDEGlobal::locale()->insertCatalogue( "amarok" );
return new UniversalAmarok(instance,par,widp,desktopname,name);
}
}
diff --git a/amarok/src/lastfm.cpp b/amarok/src/lastfm.cpp
index 0d5f3937..90976b2c 100644
--- a/amarok/src/lastfm.cpp
+++ b/amarok/src/lastfm.cpp
@@ -481,7 +481,7 @@ WebService::handshake( const TQString& username, const TQString& password )
m_proxyUrl = TQString( "http://localhost:%1/lastfm.mp3" ).arg( port );
m_server = new Amarok::ProcIO();
- m_server->setComm( KProcess::Communication( KProcess::AllOutput ) );
+ m_server->setComm( TDEProcess::Communication( TDEProcess::AllOutput ) );
*m_server << "amarok_proxy.rb";
*m_server << "--lastfm";
*m_server << TQString::number( port );
@@ -506,7 +506,7 @@ WebService::handshake( const TQString& username, const TQString& password )
return false;
connect( m_server, TQT_SIGNAL( readReady( KProcIO* ) ), this, TQT_SLOT( readProxy() ) );
- connect( m_server, TQT_SIGNAL( processExited( KProcess* ) ), Controller::instance(), TQT_SLOT( playbackStopped() ) );
+ connect( m_server, TQT_SIGNAL( processExited( TDEProcess* ) ), Controller::instance(), TQT_SLOT( playbackStopped() ) );
}
else
m_proxyUrl = m_streamUrl.toString();
diff --git a/amarok/src/loader/loader.cpp b/amarok/src/loader/loader.cpp
index d8d20864..12176080 100644
--- a/amarok/src/loader/loader.cpp
+++ b/amarok/src/loader/loader.cpp
@@ -144,7 +144,7 @@ Loader::Loader( TQStringList args )
if( !TQApplication::isSessionRestored())
{
- TDEInstance instance("amarok"); // KGlobal::dirs() crashes without
+ TDEInstance instance("amarok"); // TDEGlobal::dirs() crashes without
if( isSplashEnabled() )
{
m_splash = new KSplashScreen( TQPixmap( KStandardDirs().findResource("data", "amarok/images/splash_screen.jpg")));
@@ -214,8 +214,8 @@ bool
isSplashEnabled()
{
//determine whether splash-screen is enabled in amarokrc
- (void)KGlobal::config(); // the kubuntu special directory is not present without this
- TQStringList dirs = KGlobal::dirs()->findAllResources( "config", "amarokrc" );
+ (void)TDEGlobal::config(); // the kubuntu special directory is not present without this
+ TQStringList dirs = TDEGlobal::dirs()->findAllResources( "config", "amarokrc" );
for( TQStringList::iterator path = dirs.begin();
path != dirs.end();
diff --git a/amarok/src/magnatunebrowser/magnatunealbumdownloader.cpp b/amarok/src/magnatunebrowser/magnatunealbumdownloader.cpp
index e8dae66f..ae0d5ddc 100644
--- a/amarok/src/magnatunebrowser/magnatunealbumdownloader.cpp
+++ b/amarok/src/magnatunebrowser/magnatunealbumdownloader.cpp
@@ -90,7 +90,7 @@ void MagnatuneAlbumDownloader::albumDownloadComplete( KIO::Job * downloadJob )
//ok, now we have the .zip file downloaded. All we need is to unpack it to the desired location and add it to the collection.
- TQString unzipString = "unzip "+ KProcess::quote( m_tempDir.name() + m_currentAlbumFileName) + " -d " +KProcess::quote( m_currentAlbumUnpackLocation ) + " &";
+ TQString unzipString = "unzip "+ TDEProcess::quote( m_tempDir.name() + m_currentAlbumFileName) + " -d " +TDEProcess::quote( m_currentAlbumUnpackLocation ) + " &";
debug() << "unpacking: " << unzipString << endl;
diff --git a/amarok/src/magnatunebrowser/magnatunelistviewitems.cpp b/amarok/src/magnatunebrowser/magnatunelistviewitems.cpp
index 8ce1046c..df75d45d 100644
--- a/amarok/src/magnatunebrowser/magnatunelistviewitems.cpp
+++ b/amarok/src/magnatunebrowser/magnatunelistviewitems.cpp
@@ -34,7 +34,7 @@ MagnatuneListViewArtistItem::MagnatuneListViewArtistItem( MagnatuneArtist artist
{
KListViewItem::setText( 0, artist.getName() );
- setPixmap(0, KGlobal::iconLoader()->loadIcon( "personal", KIcon::Toolbar, KIcon::SizeSmall ) );
+ setPixmap(0, TDEGlobal::iconLoader()->loadIcon( "personal", KIcon::Toolbar, KIcon::SizeSmall ) );
setDragEnabled ( true );
}
@@ -90,7 +90,7 @@ MagnatuneListViewAlbumItem::MagnatuneListViewAlbumItem( MagnatuneAlbum album, KL
KListViewItem::setText( 0, album.getName() );
setDragEnabled( true );
- //setPixmap(0, KGlobal::iconLoader()->loadIcon( "cdrom_unmount", KIcon::Toolbar, KIcon::SizeSmall ) );
+ //setPixmap(0, TDEGlobal::iconLoader()->loadIcon( "cdrom_unmount", KIcon::Toolbar, KIcon::SizeSmall ) );
}
@@ -166,7 +166,7 @@ MagnatuneListViewTrackItem::MagnatuneListViewTrackItem( MagnatuneTrack track, KL
setDragEnabled( true );
- //setPixmap(0, KGlobal::iconLoader()->loadIcon( "track", KIcon::Toolbar, KIcon::SizeSmall ) );
+ //setPixmap(0, TDEGlobal::iconLoader()->loadIcon( "track", KIcon::Toolbar, KIcon::SizeSmall ) );
}
MagnatuneListViewTrackItem::~ MagnatuneListViewTrackItem( )
diff --git a/amarok/src/mediabrowser.cpp b/amarok/src/mediabrowser.cpp
index 7f8760da..ba5a385a 100644
--- a/amarok/src/mediabrowser.cpp
+++ b/amarok/src/mediabrowser.cpp
@@ -2452,7 +2452,7 @@ int MediaDevice::sysCall( const TQString &command )
sysProc->clearArguments();
(*sysProc) << command;
- if (!sysProc->start( KProcess::Block, KProcess::AllOutput ))
+ if (!sysProc->start( TDEProcess::Block, TDEProcess::AllOutput ))
kdFatal() << i18n("could not execute %1").arg(command.local8Bit().data()) << endl;
return (sysProc->exitStatus());
diff --git a/amarok/src/mediadevice/daap/daapclient.cpp b/amarok/src/mediadevice/daap/daapclient.cpp
index 9971ad8f..c6a32388 100644
--- a/amarok/src/mediadevice/daap/daapclient.cpp
+++ b/amarok/src/mediadevice/daap/daapclient.cpp
@@ -472,7 +472,7 @@ DaapClient::customClicked()
: KDialogBase( parent, "DaapAddHostDialog", true, i18n( "Add Computer" ) , Ok|Cancel)
{
m_base = new AddHostBase( this, "DaapAddHostBase" );
- m_base->m_downloadPixmap->setPixmap( TQPixmap( KGlobal::iconLoader()->iconPath( Amarok::icon( "download" ), -KIcon::SizeEnormous ) ) );
+ m_base->m_downloadPixmap->setPixmap( TQPixmap( TDEGlobal::iconLoader()->iconPath( Amarok::icon( "download" ), -KIcon::SizeEnormous ) ) );
m_base->m_hostName->setFocus();
setMainWidget( m_base );
}
@@ -523,7 +523,7 @@ DaapClient::passwordPrompt()
setButtonOK( ok );
TQLabel* passIcon = new TQLabel( mainWidget(), "passicon" );
- passIcon->setPixmap( TQPixmap( KGlobal::iconLoader()->iconPath( "password", -KIcon::SizeHuge ) ) );
+ passIcon->setPixmap( TQPixmap( TDEGlobal::iconLoader()->iconPath( "password", -KIcon::SizeHuge ) ) );
TQHBox* loginArea = new TQHBox( mainWidget(), "passhbox" );
new TQLabel( i18n( "Password:"), loginArea, "passlabel" );
m_input = new KPasswordEdit( loginArea, "passedit" );
diff --git a/amarok/src/mediadevice/daap/daapserver.cpp b/amarok/src/mediadevice/daap/daapserver.cpp
index de52a2ad..63953fcb 100644
--- a/amarok/src/mediadevice/daap/daapserver.cpp
+++ b/amarok/src/mediadevice/daap/daapserver.cpp
@@ -28,7 +28,7 @@ DaapServer::DaapServer(TQObject* parent, char* name)
DEBUG_BLOCK
m_server = new KProcIO();
- m_server->setComm( KProcess::All );
+ m_server->setComm( TDEProcess::All );
*m_server << "amarok_daapserver.rb";
*m_server << locate( "data", "amarok/ruby_lib/" );
*m_server << locate( "lib", "ruby_lib/" );
diff --git a/amarok/src/mediadevice/daap/proxy.cpp b/amarok/src/mediadevice/daap/proxy.cpp
index b1095cd4..d35849d6 100644
--- a/amarok/src/mediadevice/daap/proxy.cpp
+++ b/amarok/src/mediadevice/daap/proxy.cpp
@@ -58,7 +58,7 @@ Proxy::Proxy(KURL stream, DaapClient* client, const char* name)
delete socket;
m_proxyUrl = KURL( TQString("http://localhost:%1/daap.mp3").arg( port ) );
//start proxy
- m_proxy->setComm( KProcess::Communication( KProcess::AllOutput ) );
+ m_proxy->setComm( TDEProcess::Communication( TDEProcess::AllOutput ) );
*m_proxy << "amarok_proxy.rb";
*m_proxy << "--daap";
*m_proxy << TQString::number( port );
@@ -80,7 +80,7 @@ Proxy::Proxy(KURL stream, DaapClient* client, const char* name)
if( line == "AMAROK_PROXY: startup" ) break;
}
debug() << "started amarok_proxy.rb --daap " << TQString::number( port ) << ' ' << realStream.url() << ' ' << AmarokConfig::soundSystem() << ' ' << hash << ' ' << revisionId << endl;
- connect( m_proxy, TQT_SIGNAL( processExited( KProcess* ) ), this, TQT_SLOT( playbackStopped() ) );
+ connect( m_proxy, TQT_SIGNAL( processExited( TDEProcess* ) ), this, TQT_SLOT( playbackStopped() ) );
connect( m_proxy, TQT_SIGNAL( readReady( KProcIO* ) ), this, TQT_SLOT( readProxy() ) );
}
diff --git a/amarok/src/moodbar.h b/amarok/src/moodbar.h
index 9665ad0c..13f7e02d 100644
--- a/amarok/src/moodbar.h
+++ b/amarok/src/moodbar.h
@@ -111,7 +111,7 @@ private:
};
-class KProcess;
+class TDEProcess;
// For internal use only (well, mostly)
class MoodServer : public TQObject
@@ -132,7 +132,7 @@ signals:
void jobEvent( KURL url, int newState );
private slots:
- void slotJobCompleted( KProcess *proc );
+ void slotJobCompleted( TDEProcess *proc );
void slotNewJob( void );
void slotMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic );
@@ -174,7 +174,7 @@ private:
TQValueList<ProcData> m_jobQueue;
bool m_moodbarBroken;
- KProcess *m_currentProcess;
+ TDEProcess *m_currentProcess;
ProcData m_currentData;
mutable TQMutex m_mutex;
};
diff --git a/amarok/src/mountpointmanager.cpp b/amarok/src/mountpointmanager.cpp
index f0e6313f..ab1e6065 100644
--- a/amarok/src/mountpointmanager.cpp
+++ b/amarok/src/mountpointmanager.cpp
@@ -122,7 +122,7 @@ MountPointManager::init()
{
mediumChanged( &(*it) );
}
- if( !KGlobal::config()->hasGroup( "Collection Folders" ) )
+ if( !TDEGlobal::config()->hasGroup( "Collection Folders" ) )
{
TQStringList folders = AmarokConfig::collectionFolders();
if( !folders.isEmpty() )
diff --git a/amarok/src/playerwindow.cpp b/amarok/src/playerwindow.cpp
index 7cd3590e..3bbd14f3 100644
--- a/amarok/src/playerwindow.cpp
+++ b/amarok/src/playerwindow.cpp
@@ -440,7 +440,7 @@ void PlayerWidget::determineAmarokColors() //static
(!AmarokConfig::schemeKDE()
? AmarokConfig::playlistWindowBgColor()
- : KGlobalSettings::highlightColor()
+ : TDEGlobalSettings::highlightColor()
).getHsv( &hue, &s, &v );
using namespace Amarok::ColorScheme;
@@ -455,7 +455,7 @@ void PlayerWidget::determineAmarokColors() //static
//TODO schemes that have totally different active/inactive decoration colours need to be catered for too!
if ( AmarokConfig::schemeKDE() ) {
int h;
- KGlobalSettings::activeTitleColor().getHsv( &h, &s, &v );
+ TDEGlobalSettings::activeTitleColor().getHsv( &h, &s, &v );
if( TQABS( hue - h ) > 120 )
hue = h;
}
diff --git a/amarok/src/playlist.cpp b/amarok/src/playlist.cpp
index 70cddfea..529cd4c9 100644
--- a/amarok/src/playlist.cpp
+++ b/amarok/src/playlist.cpp
@@ -77,7 +77,7 @@
#include <kmessagebox.h>
#include <kpopupmenu.h>
#include <krandomsequence.h> //random Mode
-#include <kstandarddirs.h> //KGlobal::dirs()
+#include <kstandarddirs.h> //TDEGlobal::dirs()
#include <kstdaction.h>
#include <kstringhandler.h> //::showContextMenu()
#include <kurldrag.h>
@@ -369,7 +369,7 @@ Playlist::Playlist( TQWidget *parent )
engineStateChanged( EngineController::engine()->state() ); //initialise state of UI
paletteChange( palette() ); //sets up glowColors
- restoreLayout( KGlobal::config(), "PlaylistColumnsLayout" );
+ restoreLayout( TDEGlobal::config(), "PlaylistColumnsLayout" );
// Sorting must be disabled when current.xml is being loaded. See BUG 113042
KListView::setSorting( NO_SORT ); //use base so we don't saveUndoState() too
@@ -412,7 +412,7 @@ Playlist::Playlist( TQWidget *parent )
Playlist::~Playlist()
{
- saveLayout( KGlobal::config(), "PlaylistColumnsLayout" );
+ saveLayout( TDEGlobal::config(), "PlaylistColumnsLayout" );
if( AmarokConfig::savePlaylist() && m_lockStack == 0 ) saveXML( defaultPlaylistPath() );
@@ -2244,7 +2244,7 @@ Playlist::rename( TQListViewItem *item, int column ) //SLOT
break;
}
- renameLineEdit()->completionObject()->setCompletionMode( KGlobalSettings::CompletionPopupAuto );
+ renameLineEdit()->completionObject()->setCompletionMode( TDEGlobalSettings::CompletionPopupAuto );
renameLineEdit()->completionObject()->setIgnoreCase( true );
m_editOldTag = static_cast<PlaylistItem *>(item)->exactText( column );
diff --git a/amarok/src/playlistbrowser.cpp b/amarok/src/playlistbrowser.cpp
index 8819e1b4..2010a57d 100644
--- a/amarok/src/playlistbrowser.cpp
+++ b/amarok/src/playlistbrowser.cpp
@@ -56,7 +56,7 @@
#include <kmultipledrag.h> //dragObject()
#include <kpopupmenu.h>
#include <kpushbutton.h>
-#include <kstandarddirs.h> //KGlobal::dirs()
+#include <kstandarddirs.h> //TDEGlobal::dirs()
#include <kurldrag.h> //dragObject()
#include <cstdio> //rename() in renamePlaylist()
diff --git a/amarok/src/playlistbrowseritem.cpp b/amarok/src/playlistbrowseritem.cpp
index b2401e41..5ab0ed69 100644
--- a/amarok/src/playlistbrowseritem.cpp
+++ b/amarok/src/playlistbrowseritem.cpp
@@ -3485,7 +3485,7 @@ void ShoutcastBrowser::setOpen( bool open )
m_animationTimer.start( ANIMATION_INTERVAL );
connect( &m_animationTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotAnimation()) );
- TQStringList tmpdirs = KGlobal::dirs()->resourceDirs( "tmp" );
+ TQStringList tmpdirs = TDEGlobal::dirs()->resourceDirs( "tmp" );
TQString tmpfile = tmpdirs[0];
tmpfile += "/amarok-genres-" + TDEApplication::randomString(10) + ".xml-";
@@ -3643,7 +3643,7 @@ void ShoutcastGenre::setOpen( bool open )
m_animationTimer.start( ANIMATION_INTERVAL );
connect( &m_animationTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(slotAnimation()) );
- TQStringList tmpdirs = KGlobal::dirs()->resourceDirs( "tmp" );
+ TQStringList tmpdirs = TDEGlobal::dirs()->resourceDirs( "tmp" );
//get the genre list from shoutcast async, and when its done call the finish up functions to process
if( !m_downloading)
diff --git a/amarok/src/prettypopupmenu.cpp b/amarok/src/prettypopupmenu.cpp
index 6839cdbf..36bb0c5e 100644
--- a/amarok/src/prettypopupmenu.cpp
+++ b/amarok/src/prettypopupmenu.cpp
@@ -72,7 +72,7 @@ PrettyPopupMenu::sideImageRect() const
TQColor
PrettyPopupMenu::calcPixmapColor()
{
- KConfig *config = KGlobal::config();
+ KConfig *config = TDEGlobal::config();
config->setGroup("WM");
TQColor color = TQApplication::palette().active().highlight();
// TQColor activeTitle = TQApplication::palette().active().background();
diff --git a/amarok/src/scancontroller.cpp b/amarok/src/scancontroller.cpp
index fee95fd1..288f3214 100644
--- a/amarok/src/scancontroller.cpp
+++ b/amarok/src/scancontroller.cpp
@@ -83,7 +83,7 @@ ScanController::ScanController( CollectionDB* parent, bool incremental, const TQ
*m_scanner << "amarokcollectionscanner";
*m_scanner << "--nocrashhandler"; // We want to be able to catch SIGSEGV
- // KProcess must be started from the GUI thread, so we're invoking the scanner
+ // TDEProcess must be started from the GUI thread, so we're invoking the scanner
// here in the ctor:
if( incremental )
{
diff --git a/amarok/src/scriptmanager.cpp b/amarok/src/scriptmanager.cpp
index a1af8b02..f2a44639 100644
--- a/amarok/src/scriptmanager.cpp
+++ b/amarok/src/scriptmanager.cpp
@@ -522,7 +522,7 @@ ScriptManager::slotUninstallScript()
// find if the script is installed in the global or local scripts directory
KURL scriptsDirURL;
- TQStringList dirs = KGlobal::dirs()->findDirs( "data", "amarok/scripts/" );
+ TQStringList dirs = TDEGlobal::dirs()->findDirs( "data", "amarok/scripts/" );
for ( TQStringList::Iterator it = dirs.begin(); it != dirs.end(); ++it ) {
scriptsDirURL = KURL::fromPathOrURL( *it );
if ( scriptsDirURL.isParentOf( scriptDirURL ) )
@@ -588,16 +588,16 @@ ScriptManager::slotRunScript( bool silent )
if( m_scripts[name].process ) return false;
Amarok::ProcIO* script = new Amarok::ProcIO();
- script->setComm( static_cast<KProcess::Communication>( KProcess::All ) );
+ script->setComm( static_cast<TDEProcess::Communication>( TDEProcess::All ) );
const KURL url = m_scripts[name].url;
*script << url.path();
script->setWorkingDirectory( Amarok::saveLocation( "scripts-data/" ) );
- connect( script, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ), TQT_SLOT( slotReceivedStderr( KProcess*, char*, int ) ) );
- connect( script, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ), TQT_SLOT( slotReceivedStdout( KProcess*, char*, int ) ) );
- connect( script, TQT_SIGNAL( processExited( KProcess* ) ), TQT_SLOT( scriptFinished( KProcess* ) ) );
+ connect( script, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ), TQT_SLOT( slotReceivedStderr( TDEProcess*, char*, int ) ) );
+ connect( script, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ), TQT_SLOT( slotReceivedStdout( TDEProcess*, char*, int ) ) );
+ connect( script, TQT_SIGNAL( processExited( TDEProcess* ) ), TQT_SLOT( scriptFinished( TDEProcess* ) ) );
- if( script->start( KProcess::NotifyOnExit ) )
+ if( script->start( TDEProcess::NotifyOnExit ) )
{
if( m_scripts[name].type == "score" && !scoreScriptRunning().isNull() )
{
@@ -716,7 +716,7 @@ ScriptManager::slotShowContextMenu( TQListViewItem* item, const TQPoint& pos )
switch( id )
{
case EDIT:
- KRun::runCommand( "kwrite " + KProcess::quote(it.data().url.path()) );
+ KRun::runCommand( "kwrite " + TDEProcess::quote(it.data().url.path()) );
break;
case SHOW_LOG:
@@ -744,14 +744,14 @@ ScriptManager::slotShowContextMenu( TQListViewItem* item, const TQPoint& pos )
/* This is just a workaround, some scripts crash for some people if stdout is not handled. */
void
-ScriptManager::slotReceivedStdout( KProcess*, char* buf, int len )
+ScriptManager::slotReceivedStdout( TDEProcess*, char* buf, int len )
{
debug() << TQString::fromLatin1( buf, len ) << endl;
}
void
-ScriptManager::slotReceivedStderr( KProcess* process, char* buf, int len )
+ScriptManager::slotReceivedStderr( TDEProcess* process, char* buf, int len )
{
// Look up script entry in our map
ScriptMap::Iterator it;
@@ -769,7 +769,7 @@ ScriptManager::slotReceivedStderr( KProcess* process, char* buf, int len )
void
-ScriptManager::scriptFinished( KProcess* process ) //SLOT
+ScriptManager::scriptFinished( TDEProcess* process ) //SLOT
{
// Look up script entry in our map
ScriptMap::Iterator it;
diff --git a/amarok/src/scriptmanager.h b/amarok/src/scriptmanager.h
index 24e23b29..948ef0cd 100644
--- a/amarok/src/scriptmanager.h
+++ b/amarok/src/scriptmanager.h
@@ -33,7 +33,7 @@ class MetaBundle;
class ScriptManagerBase;
class TQListViewItem;
class KArchiveDirectory;
-class KProcess;
+class TDEProcess;
class KProcIO;
@@ -139,9 +139,9 @@ class ScriptManager : public KDialogBase, public EngineObserver
void slotAboutScript();
void slotShowContextMenu( TQListViewItem*, const TQPoint& );
- void slotReceivedStdout( KProcess*, char*, int );
- void slotReceivedStderr( KProcess*, char*, int );
- void scriptFinished( KProcess* process );
+ void slotReceivedStdout( TDEProcess*, char*, int );
+ void slotReceivedStderr( TDEProcess*, char*, int );
+ void scriptFinished( TDEProcess* process );
private:
/** Returns all scripts of the given \p type */
diff --git a/amarok/src/socketserver.cpp b/amarok/src/socketserver.cpp
index 98e98c27..6917767a 100644
--- a/amarok/src/socketserver.cpp
+++ b/amarok/src/socketserver.cpp
@@ -193,7 +193,7 @@ Vis::Selector::Selector( TQWidget *parent )
}
void
-Vis::Selector::processExited( KProcess *proc )
+Vis::Selector::processExited( TDEProcess *proc )
{
for( Item *item = static_cast<Item*>( firstChild() ); item; item = static_cast<Item*>( item->nextSibling() ) )
if( item->m_proc == proc )
@@ -202,7 +202,7 @@ Vis::Selector::processExited( KProcess *proc )
// Shouldn't be necessary, but it's part of a fix to make libvisual work again when running with amarok binary
void
-Vis::Selector::receivedStdout( KProcess */*proc*/, char* buffer, int length )
+Vis::Selector::receivedStdout( TDEProcess */*proc*/, char* buffer, int length )
{
debug() << TQString::fromLatin1( buffer, length ) << endl;
}
@@ -286,11 +286,11 @@ Vis::Selector::Item::stateChange( bool ) //SLOT
<< Selector::instance()->m_server->path()
<< text( 0 );
- connect( m_proc, TQT_SIGNAL(processExited( KProcess* )), listView(), TQT_SLOT(processExited( KProcess* )) );
+ connect( m_proc, TQT_SIGNAL(processExited( TDEProcess* )), listView(), TQT_SLOT(processExited( TDEProcess* )) );
// Shouldn't be necessary, but make visualizations work again when running with amarok binary
- connect( m_proc, TQT_SIGNAL(receivedStdout (KProcess*, char*, int ) ), listView(), TQT_SLOT(receivedStdout (KProcess*, char*, int ) ) );
+ connect( m_proc, TQT_SIGNAL(receivedStdout (TDEProcess*, char*, int ) ), listView(), TQT_SLOT(receivedStdout (TDEProcess*, char*, int ) ) );
debug() << "Starting visualization..\n";
- if( m_proc->start( KProcess::NotifyOnExit, KProcess::AllOutput ) )
+ if( m_proc->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
break;
//ELSE FALL_THROUGH
diff --git a/amarok/src/socketserver.h b/amarok/src/socketserver.h
index fb2de226..bcc173b7 100644
--- a/amarok/src/socketserver.h
+++ b/amarok/src/socketserver.h
@@ -17,7 +17,7 @@
#include <tqsocketnotifier.h> //baseclass
class TQPoint;
-class KProcess;
+class TDEProcess;
namespace Amarok
@@ -88,7 +88,7 @@ namespace Vis
virtual void stateChange( bool state );
- KProcess *m_proc;
+ TDEProcess *m_proc;
int m_sockfd;
const char *m_command;
};
@@ -97,8 +97,8 @@ namespace Vis
void rightButton( TQListViewItem*, const TQPoint&, int );
public slots:
- void processExited( KProcess* );
- void receivedStdout( KProcess*, char*, int );
+ void processExited( TDEProcess* );
+ void receivedStdout( TDEProcess*, char*, int );
};
} //namespace VIS
diff --git a/amarok/src/starmanager.cpp b/amarok/src/starmanager.cpp
index 27aa737e..9070dd23 100644
--- a/amarok/src/starmanager.cpp
+++ b/amarok/src/starmanager.cpp
@@ -25,7 +25,7 @@
#include <tqimage.h>
#include <tqpixmap.h>
-#include <kstandarddirs.h> //KGlobal::dirs()
+#include <kstandarddirs.h> //TDEGlobal::dirs()
StarManager* StarManager::instance()
{
diff --git a/amarok/src/statusbar/queueLabel.cpp b/amarok/src/statusbar/queueLabel.cpp
index c25431f2..a1480dad 100644
--- a/amarok/src/statusbar/queueLabel.cpp
+++ b/amarok/src/statusbar/queueLabel.cpp
@@ -75,7 +75,7 @@ void QueueLabel::getCover( const TQString &artist, const TQString &album )
{
m_cover = CollectionDB::instance()->albumImage( artist, album, 50 );
if( m_cover == CollectionDB::instance()->notAvailCover( 50 ) )
- m_cover = KGlobal::iconLoader()->iconPath( "goto", -KIcon::SizeHuge );
+ m_cover = TDEGlobal::iconLoader()->iconPath( "goto", -KIcon::SizeHuge );
}
void QueueLabel::setNum( int num )
diff --git a/amarok/src/statusbar/selectLabel.h b/amarok/src/statusbar/selectLabel.h
index 5e942686..37738db9 100644
--- a/amarok/src/statusbar/selectLabel.h
+++ b/amarok/src/statusbar/selectLabel.h
@@ -146,7 +146,7 @@ class SelectLabel : public TQLabel
m_tooltip->setShowCounter( false );
m_tooltip->setMaskEffect( KDE::PopupMessage::Plain );
m_tooltip->setText( tip );
- const TQPixmap pix = KGlobal::iconLoader()
+ const TQPixmap pix = TDEGlobal::iconLoader()
->loadIconSet( m_action->currentIcon(), KIcon::Toolbar, KIcon::SizeHuge )
.pixmap( TQIconSet::Large, m_action->isEnabled()
? TQIconSet::Normal
diff --git a/amarok/src/statusbar/statusBarBase.cpp b/amarok/src/statusbar/statusBarBase.cpp
index 957e7a77..36cc912d 100644
--- a/amarok/src/statusbar/statusBarBase.cpp
+++ b/amarok/src/statusbar/statusBarBase.cpp
@@ -297,16 +297,16 @@ StatusBar::longMessage( const TQString &text, int type )
{
case Information:
case Question:
- image = KGlobal::iconLoader()->iconPath( "messagebox_info", -KIcon::SizeHuge );
+ image = TDEGlobal::iconLoader()->iconPath( "messagebox_info", -KIcon::SizeHuge );
break;
case Sorry:
case Warning:
- image = KGlobal::iconLoader()->iconPath( "messagebox_warning", -KIcon::SizeHuge );
+ image = TDEGlobal::iconLoader()->iconPath( "messagebox_warning", -KIcon::SizeHuge );
break;
case Error:
- image = KGlobal::iconLoader()->iconPath( "messagebox_critical", -KIcon::SizeHuge );
+ image = TDEGlobal::iconLoader()->iconPath( "messagebox_critical", -KIcon::SizeHuge );
// don't hide error messages.
// message->setTimeout( 0 );
break;
@@ -669,7 +669,7 @@ StatusBar::writeLogFile( const TQString &text )
TQTextStream stream( &file );
stream.setEncoding( TQTextStream::UnicodeUTF8 );
- stream << "[" << KGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() ) << "] " << text << endl;
+ stream << "[" << TDEGlobal::locale()->formatDateTime( TQDateTime::currentDateTime() ) << "] " << text << endl;
}
} //namespace KDE
diff --git a/amarok/src/statusbar/timeLabel.h b/amarok/src/statusbar/timeLabel.h
index ec703b93..1cd06f13 100644
--- a/amarok/src/statusbar/timeLabel.h
+++ b/amarok/src/statusbar/timeLabel.h
@@ -27,7 +27,7 @@ class TimeLabel : public TQLabel
public:
TimeLabel( TQWidget *parent ) : TQLabel( " 0:00:00 ", parent )
{
- setFont( KGlobalSettings::fixedFont() );
+ setFont( TDEGlobalSettings::fixedFont() );
setSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Fixed );
}
diff --git a/amarok/src/statusbar/toggleLabel.h b/amarok/src/statusbar/toggleLabel.h
index dce06d4b..7c840c38 100644
--- a/amarok/src/statusbar/toggleLabel.h
+++ b/amarok/src/statusbar/toggleLabel.h
@@ -116,7 +116,7 @@ class ToggleLabel : public TQLabel
tip += i18n("&nbsp;<br>&nbsp;<i>Disabled</i>");
tip += "&nbsp;";
- const TQString path = KGlobal::iconLoader()->iconPath( m_action->icon(), -KIcon::SizeHuge );
+ const TQString path = TDEGlobal::iconLoader()->iconPath( m_action->icon(), -KIcon::SizeHuge );
m_tooltip = new KDE::PopupMessage( parentWidget()->parentWidget(), parentWidget(), 0 /*timeout*/ );
diff --git a/amarok/src/tagdialog.cpp b/amarok/src/tagdialog.cpp
index 98b6ed88..5305e8c4 100644
--- a/amarok/src/tagdialog.cpp
+++ b/amarok/src/tagdialog.cpp
@@ -391,19 +391,19 @@ void TagDialog::init()
kComboBox_artist->insertStringList( artists );
kComboBox_artist->completionObject()->insertItems( artists );
kComboBox_artist->completionObject()->setIgnoreCase( true );
- kComboBox_artist->setCompletionMode( KGlobalSettings::CompletionPopup );
+ kComboBox_artist->setCompletionMode( TDEGlobalSettings::CompletionPopup );
const TQStringList albums = CollectionDB::instance()->albumList();
kComboBox_album->insertStringList( albums );
kComboBox_album->completionObject()->insertItems( albums );
kComboBox_album->completionObject()->setIgnoreCase( true );
- kComboBox_album->setCompletionMode( KGlobalSettings::CompletionPopup );
+ kComboBox_album->setCompletionMode( TDEGlobalSettings::CompletionPopup );
const TQStringList composers = CollectionDB::instance()->composerList();
kComboBox_composer->insertStringList( composers );
kComboBox_composer->completionObject()->insertItems( composers );
kComboBox_composer->completionObject()->setIgnoreCase( true );
- kComboBox_composer->setCompletionMode( KGlobalSettings::CompletionPopup );
+ kComboBox_composer->setCompletionMode( TDEGlobalSettings::CompletionPopup );
kComboBox_rating->insertStringList( MetaBundle::ratingList() );
@@ -685,9 +685,9 @@ void TagDialog::readTags()
summaryText += body2cols.arg( i18n("Playcount"), TQString::number( m_bundle.playCount() ) );
summaryText += body2cols.arg( i18n("First Played"),
- m_bundle.playCount() ? KGlobal::locale()->formatDate( CollectionDB::instance()->getFirstPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
+ m_bundle.playCount() ? TDEGlobal::locale()->formatDate( CollectionDB::instance()->getFirstPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
summaryText += body2cols.arg( i18n("a single item (singular)", "Last Played"),
- m_bundle.playCount() ? KGlobal::locale()->formatDate( CollectionDB::instance()->getLastPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
+ m_bundle.playCount() ? TDEGlobal::locale()->formatDate( CollectionDB::instance()->getLastPlay( m_bundle.url().path() ).date() , true ) : i18n("Never") );
summaryText += "</table></td></tr></table>";
summaryLabel->setText( summaryText );
diff --git a/amarok/src/tagguesser.cpp b/amarok/src/tagguesser.cpp
index 1fe60553..deb85a3d 100644
--- a/amarok/src/tagguesser.cpp
+++ b/amarok/src/tagguesser.cpp
@@ -134,7 +134,7 @@ TQString FileNameScheme::composeRegExp( const TQString &s ) const
{
TQMap<TQString, TQString> substitutions;
- KConfigGroup config(KGlobal::config(), "TagGuesser");
+ KConfigGroup config(TDEGlobal::config(), "TagGuesser");
substitutions[ "title" ] = config.readEntry( "Title regexp", "([\\w\\s'&_,\\.]+)" );
substitutions[ "artist" ] = config.readEntry( "Artist regexp", "([\\w\\s'&_,\\.]+)" );
@@ -195,7 +195,7 @@ TQStringList TagGuesser::schemeStrings()
void TagGuesser::setSchemeStrings( const TQStringList &schemes )
{
- KConfig *cfg = KGlobal::config();
+ KConfig *cfg = TDEGlobal::config();
{
KConfigGroupSaver saver( cfg, "TagGuesser" );
cfg->writeEntry( "Filename schemes", schemes );
diff --git a/amarok/src/amarok.h b/amarok/src/amarok.h
index 984b5709..0067df17 100644
--- a/amarok/src/amarok.h
+++ b/amarok/src/amarok.h
@@ -166,12 +166,12 @@ namespace Amarok
{
return fileName.section( '/', 0, -2 );
}
/** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
* Used by Amarok::ProcIO and Amarok::Process, exploiting commSetupDoneC(), a virtual method that
* happens to be called in the forked process
* See bug #103750 for more information.
*/
//TODO ugly hack, fix KProcess for KDE 4.0
void closeOpenFiles(int out, int in, int err); //defined in scriptmanager.cpp
/**
@@ -268,7 +268,7 @@ namespace Amarok
// class Amarok::ProcIO
////////////////////////////////////////////////////////////////////////////////
/**
* Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
* Used by Amarok::ProcIO and AmarokProcess, exploiting commSetupDoneC(), a virtual method that
* happens to be called in the forked process
* See bug #103750 for more information.
@@ -286,17 +286,17 @@ namespace Amarok
////////////////////////////////////////////////////////////////////////////////
// class Amarok::Process
////////////////////////////////////////////////////////////////////////////////
/** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
* Used by Amarok::ProcIO and Amarok::Process, exploiting commSetupDoneC(), a virtual method that
* happens to be called in the forked process
* See bug #103750 for more information.
*/
- class LIBAMAROK_EXPORT Process : public KProcess {
+ class LIBAMAROK_EXPORT Process : public TDEProcess {
public:
- Process( TQObject *parent = 0 ) : KProcess( parent ) {}
+ Process( TQObject *parent = 0 ) : TDEProcess( parent ) {}
virtual int commSetupDoneC() {
- const int i = KProcess::commSetupDoneC();
- Amarok::closeOpenFiles(KProcess::out[0],KProcess::in[0], KProcess::err[0]);
+ const int i = TDEProcess::commSetupDoneC();
+ Amarok::closeOpenFiles(TDEProcess::out[0],TDEProcess::in[0], TDEProcess::err[0]);
return i;
};
};
@@ -166,12 +166,12 @@ namespace Amarok
return fileName.section( '/', 0, -2 );
}
- /** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
+ /** Due to xine-lib, we have to make TDEProcess close all fds, otherwise we get "device is busy" messages
* Used by Amarok::ProcIO and Amarok::Process, exploiting commSetupDoneC(), a virtual method that
* happens to be called in the forked process
@@ -166,12 +166,12 @@ namespace Amarok
* See bug #103750 for more information.
*/
- //TODO ugly hack, fix KProcess for KDE 4.0
+ //TODO ugly hack, fix TDEProcess for KDE 4.0
void closeOpenFiles(int out, int in, int err); //defined in scriptmanager.cpp
/**
@@ -268,7 +268,7 @@ namespace Amarok
////////////////////////////////////////////////////////////////////////////////
/**
- * Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
+ * Due to xine-lib, we have to make TDEProcess close all fds, otherwise we get "device is busy" messages
* Used by Amarok::ProcIO and AmarokProcess, exploiting commSetupDoneC(), a virtual method that
* happens to be called in the forked process
@@ -286,17 +286,17 @@ namespace Amarok
// class Amarok::Process
////////////////////////////////////////////////////////////////////////////////
- /** Due to xine-lib, we have to make KProcess close all fds, otherwise we get "device is busy" messages
+ /** Due to xine-lib, we have to make TDEProcess close all fds, otherwise we get "device is busy" messages
* Used by Amarok::ProcIO and Amarok::Process, exploiting commSetupDoneC(), a virtual method that
* happens to be called in the forked process
diff --git a/amarok/src/moodbar.cpp b/amarok/src/moodbar.cpp
index a67e31cc..1c037c6b 100644
--- a/amarok/src/moodbar.cpp
+++ b/amarok/src/moodbar.cpp
@@ -223,16 +223,16 @@
// then decides to clear the playlist again. The jobEvent() signal
// passes the URL of the job that was completed.
//
// The analyzer is actually run using a KProcess. ThreadManager::Job
// is not a good solution, since we need more flexibility in the
// queuing process, and in addition, KProcess'es must be started from
// the GUI thread!
//
// Important members:
// m_jobQueue: this is a list of MoodServer::ProcData structures,
// which contain the data needed to start and reference
// a process, as well as a refcount.
// m_currentProcess: the currently-running KProcess, if any.
// m_currentData: the ProcData structure for the currently-running
// process.
// m_moodbarBroken: this is set when there's an error running the analyzer
@@ -257,7 +257,7 @@
// necessary; otherwise call slotNewJob().
//
// (private slot) slotNewJob(): Called by slotJobCompleted() and queueJob().
// Take a job off the queue and start the KProcess.
//
// (private slot) slotMoodbarPrefs(): Called when the Amarok config changes.
// If the moodbar has been disabled completely, kill the current job
@@ -476,14 +476,14 @@ MoodServer::slotNewJob( void )
<< (m_currentData.m_outfile + ".tmp")
<< m_currentData.m_infile;
- connect( m_currentProcess, TQT_SIGNAL( processExited( KProcess* ) ),
- TQT_SLOT( slotJobCompleted( KProcess* ) ) );
+ connect( m_currentProcess, TQT_SIGNAL( processExited( TDEProcess* ) ),
+ TQT_SLOT( slotJobCompleted( TDEProcess* ) ) );
- // We have to enable KProcess::Stdout (even though we don't monitor
+ // We have to enable TDEProcess::Stdout (even though we don't monitor
// it) since otherwise the child process crashes every time in
// KProcess::start() (but only when started from the loader!). I
// have no idea why, but I imagine it's a bug in KDE.
- if( !m_currentProcess->start( KProcess::NotifyOnExit, KProcess::AllOutput ) )
+ if( !m_currentProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) )
{
// If we have an error starting the process, it's never
// going to work, so call moodbarBroken()
@@ -506,7 +506,7 @@ MoodServer::slotNewJob( void )
// This always run in the GUI thread. It is called
// when an analyzer process terminates
void
-MoodServer::slotJobCompleted( KProcess *proc )
+MoodServer::slotJobCompleted( TDEProcess *proc )
{
m_mutex.lock();
@@ -223,16 +223,16 @@
// passes the URL of the job that was completed.
//
-// The analyzer is actually run using a KProcess. ThreadManager::Job
+// The analyzer is actually run using a TDEProcess. ThreadManager::Job
// is not a good solution, since we need more flexibility in the
@@ -223,16 +223,16 @@
// is not a good solution, since we need more flexibility in the
-// queuing process, and in addition, KProcess'es must be started from
+// queuing process, and in addition, TDEProcess'es must be started from
// the GUI thread!
//
@@ -223,16 +223,16 @@
// which contain the data needed to start and reference
// a process, as well as a refcount.
-// m_currentProcess: the currently-running KProcess, if any.
+// m_currentProcess: the currently-running TDEProcess, if any.
// m_currentData: the ProcData structure for the currently-running
// process.
@@ -257,7 +257,7 @@
//
// (private slot) slotNewJob(): Called by slotJobCompleted() and queueJob().
-// Take a job off the queue and start the KProcess.
+// Take a job off the queue and start the TDEProcess.
//
// (private slot) slotMoodbarPrefs(): Called when the Amarok config changes.
@@ -476,14 +476,14 @@ MoodServer::slotNewJob( void )
// it) since otherwise the child process crashes every time in
- // KProcess::start() (but only when started from the loader!). I
+ // TDEProcess::start() (but only when started from the loader!). I
// have no idea why, but I imagine it's a bug in KDE.